The property mecanism
---------------------
XXX CWProperty and co


Property API
~~~~~~~~~~~~
XXX feed me

Registering and using your own property
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
XXX feed me
